@@ -52,6 +52,8 @@ class DjangoStorage(BaseStorage):
                 id=message.id,
                 default=message.default,
                 default_plural=message.default_plural,
+                context=message.context,
+                has_plural=message.has_plural,
                 translations={
                     translation.locale: StorageTranslation(
                         singular=translation.singular,
@@ -82,6 +84,18 @@ class DjangoStorage(BaseStorage):
         for message in messages:
             if message.id in self.storage:
                 unused_messages.remove(message.id)
+
+                saved_message = self.storage[message.id]
+                if (
+                    message.number_of_non_default_attributes
+                    >= saved_message.number_of_non_default_attributes
+                ):
+                    logger.debug(
+                        "Message '%s' has more non-default attributes, updating...",
+                        message,
+                    )
+                    self.storage[message.id] = message
+
                 continue
 
             logger.debug(
@@ -99,7 +113,12 @@ class DjangoStorage(BaseStorage):
                     self._init_message_model(message)
                     for message in self.storage.values()
                 ),
-                fields=("default", "default_plural"),
+                fields=(
+                    "default",
+                    "default_plural",
+                    "has_plural",
+                    "context",
+                ),
             )
         )
         await self.message_model.objects.filter(
@@ -122,4 +141,5 @@ class DjangoStorage(BaseStorage):
             default=storage_message.default,
             default_plural=storage_message.default_plural,
             context=storage_message.context,
+            has_plural=storage_message.has_plural,
         )
